@@ -3,7 +3,7 @@
 {
     if(!inherits(n, c("rda", "cca")))
         stop("'n' not of class \"cca\" or \"rda\"")
-    if(!is.null(n$CCA))
+    if(!is.null(n$CCA) && n$CCA$rank > 0)
         stop("'bstick' only for unconstrained models.")
     ## No idea how to define bstick for capscale with negative
     ## eigenvalues
