@@ -6,7 +6,7 @@
   cat("Correlation in a symmetric Procrustes rotation:  ")
   cat(formatC(x$t0, digits = digits), "\n")
   cat("Significance:  ")
-  cat(format.pval(x$signif, eps = 1/x$permutations),"\n")
+  cat(format.pval(x$signif),"\n")
   cat("Based on", x$permutations, "permutations")
   if (!is.null(x$strata)) 
     cat(", stratified within", x$strata)
